PALM-meteo: palmmeteo.plugins.PluginMeta Class Reference

PALM-meteo

Public Member Functions | List of all members
palmmeteo.plugins.PluginMeta Class Reference
Inheritance diagram for palmmeteo.plugins.PluginMeta:
[legend]
Collaboration diagram for palmmeteo.plugins.PluginMeta:
[legend]

## Public Member Functions
def | __new__ (cls, name, bases, dct)

## Detailed Description

    Meta class for plugin classes

    Inherits from ABCMeta so we can use @abstractmethod decorator in plugin
    mixins.

    Checks for event handler methods in plugins and fills in event_hooks list.
    Allows only one method name to be the handler of a specific event.
    E.g. ImportPluginMixin registers event 'import' with 'import_data' method as
    its handler. Import plugins inherited from ImportPluginMixin then must
    implement 'import_data' method to handle the 'import' event.

## Member Function Documentation

## ◆ __new__()

def palmmeteo.plugins.PluginMeta.__new__ | ( |  | cls,
|  |  | name,
|  |  | bases,
|  |  | dct
| ) |  |

The documentation for this class was generated from the following file:

- palmmeteo/plugins.py